@@ -3,22 +3,37 @@ import json
 import time
 import os
 
+from resources import getResourceName
+
 class quantum_lab():
 
     def __init__(self,
             resourceId: int,
-            volumeName: str, 
-            resourceName: str
+            volumeName: str
         ):
         self.userID = os.environ["QCC_USER_ID"]
         # self.uploadType = uploadType
         # self.shot = shot
         self.resourceId = resourceId
         # self.filePath = filePath
-        self.volumeName = volumeName
-        self.resourceName = resourceName
+        self.volumeName = self.getDirpath(volumeName)
+        self.resourceName = getResourceName(self.resourceId)
         self.url = "http://job-management.qcc.svc.cluster.local"
 
+        if not isinstance(self.volumeName, str):
+            raise TypeError(f"{volumeName} not found.")
+        if "ERROR" in self.resourceName:
+            raise ValueError(f"{resourceId} not found.")
+
+
+    def getDirpath(self, dirPath):
+        dirList = os.listdir(f"/home/jovyan/{dirPath}")
+        for dirName in dirList:
+            if self.volumeName == dirName:
+                return f"/home/jovyan/{dirName}"
+        return 0
+
+
     def error_handler(self, response):
         if response.status_code == 204:
             print(f"Status: {response.status_code}")
